@@ -12,8 +12,8 @@ import yaml
 from clamfig import deserialize
 from clamfig import Serializable
 from clamfig import serialize
-from yaml import CDumper as Dumper
-from yaml import CLoader as Loader
+from yaml import Dumper as Dumper
+from yaml import Loader as Loader
 
 from telliot_core.utils.home import telliot_homedir
 
