@@ -2,9 +2,10 @@ import logging
 import sys
 from logging.handlers import RotatingFileHandler
 
-from telliot_core.plugin.discover import telliot_plugins
 from telliot_core.utils.home import default_homedir
 
+# from telliot_core.plugin.discover import telliot_plugins
+
 log_core = logging.getLogger("telliot_core")
 
 
@@ -33,12 +34,12 @@ def init_logging(level: int) -> logging.Logger:
     log_core.addHandler(fh)
     log_core.addHandler(stream)
 
-    # Add handlers to plugins
-    for plugin_name in telliot_plugins.keys():
-        plugin_logger = logging.getLogger(plugin_name)
-        plugin_logger.setLevel(logging.DEBUG)
-        plugin_logger.addHandler(stream)
-        plugin_logger.addHandler(fh)
-        log_core.debug(f"Configured logging for {plugin_name} plugin")
+    # # Add handlers to plugins
+    # for plugin_name in telliot_plugins.keys():
+    #     plugin_logger = logging.getLogger(plugin_name)
+    #     plugin_logger.setLevel(logging.DEBUG)
+    #     plugin_logger.addHandler(stream)
+    #     plugin_logger.addHandler(fh)
+    #     log_core.debug(f"Configured logging for {plugin_name} plugin")
 
     return log_core
